"""The enum definitions for the last line's text-align CSS
property (`text-align-last`).
"""

from enum import Enum


class CssTextAlignLast(Enum):
    """
    The enum definitions for the last line's text-align CSS
    property (`text-align-last`).
    """

    AUTO = "auto"
    LEFT = "left"
    CENTER = "center"
    RIGHT = "right"
    JUSTIFY = "justify"
