"""The material color names definitions.
"""

from typing import Literal

MaterialColorNames = Literal[
    "primary",
    "on_primary",
    "secondary",
    "on_secondary",
    "error",
    "on_error",
    "surface",
    "on_surface",
    "primary_container",
    "on_primary_container",
    "secondary_container",
    "on_secondary_container",
    "tertiary",
    "on_tertiary",
    "tertiary_container",
    "on_tertiary_container",
    "error_container",
    "on_error_container",
    "outline",
    "outline_variant",
]
