"""The definitions of the material design button constants.
"""

BUTTON_HEIGHT: int = 40

# The outer padding when there is no icon on a button.
NO_ICON_OUTER_PADDING: int = 24

ICON_SIZE: int = 18

ICON_Y: int = (BUTTON_HEIGHT - ICON_SIZE) // 2

# The outer padding when there is an icon on a button.
ICON_OUTER_PADDING_WIDTH: int = 16

# The inner padding between an icon and a label text.
ICON_INNER_PADDING_WIDTH: int = 8
