"""Enum definition for the y-axis label position.
"""

from enum import Enum


class YAxisLabelPosition(Enum):
    OUTER_TOP = "outer_top"
    OUTER_CENTER = "outer_center"
    OUTER_BOTTOM = "outer_bottom"
    INNER_TOP = "inner_top"
    INNER_CENTER = "inner_center"
    INNER_RIGHT = "inner_right"
