"""Enum definition for the x-axis label position.
"""

from enum import Enum


class XAxisLabelPosition(Enum):
    OUTER_LEFT = "outer_left"
    OUTER_CENTER = "outer_center"
    OUTER_RIGHT = "outer_right"
    INNER_LEFT = "inner_left"
    INNER_CENTER = "inner_center"
    INNER_RIGHT = "inner_right"
