"""The enum definition for the material design brightness (light or dark).
"""

from enum import Enum


class MaterialBrightness(Enum):
    """The enum class for the material design brightness (light or dark)."""

    LIGHT = "light"
    DARK = "dark"
